//+------------------------------------------------------------------+
//|                                              LBR 3 10 Osc.mq4 |
//|                        Copyright 2015, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2015, MetaQuotes Software Corp. ~ Edited 28/07/2016"
#property link      "http://www.mql5.com"
#property version   "1.00"
#property strict
//--
#include <MovingAverages.mqh>
//--
#property indicator_separate_window
//--- indicator settings
#property  indicator_separate_window
#property  indicator_buffers 4
#property  indicator_color1  clrYellow
#property  indicator_color2  clrSeaGreen
#property  indicator_color3  clrRed
#property  indicator_color4  clrCornflowerBlue
#property  indicator_level1  0	
#property  indicator_levelcolor  Black
#property  indicator_levelstyle STYLE_SOLID
//-
#property  indicator_width1  2
#property  indicator_width2  3
#property  indicator_width3  3
#property  indicator_width4  3
//-
//--- indicator parameters
input int InpFastSMA=3;   // Fast SMA Period
input int InpSlowSMA=10;   // Slow SMA Period
input int InpSignalSMA=16;  // Signal SMA Period
input int InpHistogramLineSMA=1;    // HistogramLine SMA Period
//--- indicator buffers
double ExtMacdBuff[];
double ExtSignBuff[];
double ExtMacdBuffUp[];
double ExtMacdBuffDn[];
//-
double now;
double pas;
//--- right input parameters flag
bool ExtParameters=false;
int digit;
//--
void EventSetTimer();
//--
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int OnInit(void)
  {
   //-- Checking the Digits Point
   if(Digits==3||Digits==5)
      {digit=Digits;}
   else {digit=Digits+1;}
   IndicatorDigits(digit);
   //--
//--- indicator buffers mapping
   SetIndexBuffer(0,ExtMacdBuff);
   SetIndexBuffer(1,ExtMacdBuffUp);   
   SetIndexBuffer(2,ExtMacdBuffDn);
   SetIndexBuffer(3,ExtSignBuff);
   //--
//--- drawing settings
   SetIndexStyle(0,DRAW_LINE);
   SetIndexStyle(1,DRAW_HISTOGRAM);  
   SetIndexStyle(2,DRAW_HISTOGRAM);
   SetIndexStyle(3,DRAW_LINE);
   //-
   SetIndexDrawBegin(1,InpSignalSMA);   
   SetIndexDrawBegin(2,InpSignalSMA);
   SetIndexDrawBegin(3,InpSignalSMA);
   //--
//--- name for DataWindow and indicator subwindow label
   IndicatorShortName("LBR 3 10 Osc ("+IntegerToString(InpFastSMA)+","+IntegerToString(InpSlowSMA)+","+IntegerToString(InpSignalSMA)+")");
   SetIndexLabel(0,"MACD");
   SetIndexLabel(1,"MACD Up");
   SetIndexLabel(2,"MACD Dn");
   SetIndexLabel(3,"Signal");
//--- check for input parameters
   if(InpFastSMA<=1 || InpSlowSMA<=1 || InpSignalSMA<=1 || InpFastSMA>=InpSlowSMA)
     {
      Print("Wrong input parameters");
      ExtParameters=false;
      return(INIT_FAILED);
     }
   else
      ExtParameters=true;
//--- initialization done
   return(INIT_SUCCEEDED);
  }
//--
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
//----
   EventKillTimer();
   GlobalVariablesDeleteAll();
//----
   return;
  }
//---
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
  {
//---
   int i,limit;
//---
   if(rates_total<=InpSignalSMA || !ExtParameters)
      return(0);
//--- last counted bar will be recounted
   limit=rates_total-prev_calculated;
   if(prev_calculated>0)
      limit++;
//--- counting from rates_total to 0 
   ArraySetAsSeries(ExtMacdBuff,true);
   ArraySetAsSeries(ExtSignBuff,true);
   ArraySetAsSeries(ExtMacdBuffUp,true);
   ArraySetAsSeries(ExtMacdBuffDn,true);
   //--
//--- macd counted in the 1-st buffer
   for(i=limit-1; i>=0; i--)
     {ExtMacdBuff[i]=iMA(NULL,0,InpFastSMA,0,MODE_SMA,PRICE_CLOSE,i)-
                     iMA(NULL,0,InpSlowSMA,0,MODE_SMA,PRICE_CLOSE,i);}
//--- signal line counted in the 2-nd buffer
   SimpleMAOnBuffer(rates_total,prev_calculated,0,InpSignalSMA,ExtMacdBuff,ExtSignBuff);
   //--
   for(i=limit-1; i>=0; i--)
     {
       //--
       //now=ExtMacdBuff[i]-ExtSignBuff[i];
       now=ExtMacdBuff[i];
       //--
       if(now>pas)
         {
           ExtMacdBuffUp[i]=ExtMacdBuff[i];
           ExtMacdBuffDn[i]=0.00;
         }
       //--
       if(now<pas)
         {
           ExtMacdBuffUp[i]=0.00;
           ExtMacdBuffDn[i]=ExtMacdBuff[i];
         }
       //--
       pas=now;
       //--
     }
     //--
//--- done
   return(rates_total);   
//--- return value of prev_calculated for next call
  }
//+------------------------------------------------------------------+
